@@ -2,6 +2,7 @@ import requests
 import pickle
 import time
 import logging
+import json
 import yaml
 from pathlib import Path
 
@@ -24,8 +25,31 @@ class Lupusec:
         self.session = requests.Session()
         self.session.auth = (username, password)
         self.api_url = "http://{}/action/".format(ip_address)
-        self._request_post("login")
+        self.model = "unknown"
+        self.headers = None
+        response = self._request_get("tokenGet")
 
+        if response.status_code == 404:
+            resp = self.session.get(CONST.DEVICES_API_XT1)
+            if resp.status_code == 200:
+                _LOGGER.debug("XT1 found, setting it up")
+                self.model = 1
+                self.mode_translation = CONST.MODE_TRANSLATION_XT1
+                self.api_mode = "mode_st"
+                self.api_sensors = CONST.DEVICES_API_XT1
+                self.api_device_id = "no"
+                self._request_post("login")
+            else:
+                _LOGGER.debug("Unknown error while finding out which model is used")
+                return
+        else:
+            _LOGGER.debug("XT2 or higher found, setting up")
+            self.model = 2
+            self.mode_translation = CONST.MODE_TRANSLATION_XT2
+            self.api_mode = "mode_a1"
+            self.api_sensors = CONST.DEVICES_API_XT2
+            self.api_device_id = "sid"
+            self.headers = {"X-Token": json.loads(response.text)["message"]}
         self._mode = None
         self._devices = None
 
@@ -45,11 +69,13 @@ class Lupusec:
         self._cachePss = None
         self._cacheStampP = time.time()
 
-        if get_devices or self._devices == None:
+        if get_devices or self._devices is None:
             self.get_devices()
 
     def _request_get(self, action):
-        response = self.session.get(self.api_url + action, timeout=15)
+        response = self.session.get(
+            self.api_url + action, timeout=15, headers=self.headers
+        )
         _LOGGER.debug(
             "Action and statuscode of apiGET command: %s, %s",
             action,
@@ -58,20 +84,25 @@ class Lupusec:
         return response
 
     def _request_post(self, action, params={}):
-        return self.session.post(self.api_url + action, data=params)
+        return self.session.post(
+            self.api_url + action, data=params, headers=self.headers
+        )
 
     def clean_json(self, textdata):
         _LOGGER.debug("Input for clean json" + textdata)
-        textdata = textdata.replace("\t", "")
-        i = textdata.index("\n")
-        textdata = textdata[i + 1 : -2]
-        try:
-            textdata = yaml.load(textdata, Loader=yaml.BaseLoader)
-        except Exception as e:
-            _LOGGER.warning(
-                "Lupupy couldn't parse provided response: %s, %s", e, textdata
-            )
-        return textdata
+        if self.model == 1:
+            textdata = textdata.replace("\t", "")
+            i = textdata.index("\n")
+            textdata = textdata[i + 1 : -2]
+            try:
+                textdata = yaml.load(textdata, Loader=yaml.BaseLoader)
+            except Exception as e:
+                _LOGGER.warning(
+                    "Lupupy couldn't parse provided response: %s, %s", e, textdata
+                )
+            return textdata
+        else:
+            return json.loads(textdata)
 
     def get_power_switches(self):
         stampNow = time.time()
@@ -101,14 +132,14 @@ class Lupusec:
         stamp_now = time.time()
         if self._cacheSensors is None or stamp_now - self._cacheStampS > 2.0:
             self._cacheStampS = stamp_now
-            response = self._request_get("sensorListGet")
+            response = self._request_get(self.api_sensors)
             response = self.clean_json(response.text)["senrows"]
             sensors = []
             for device in response:
                 device["status"] = device["cond"]
-                device["device_id"] = device["no"]
+                device["device_id"] = device[self.api_device_id]
                 device.pop("cond")
-                device.pop("no")
+                device.pop(self.api_device_id)
                 if not device["status"]:
                     device["status"] = "Geschlossen"
                 else:
@@ -125,24 +156,32 @@ class Lupusec:
         if response.status_code != 200:
             raise Exception("Unable to get panel " + response.status_code)
         panel = self.clean_json(response.text)["updates"]
-        panel["mode"] = panel["mode_st"]
-        panel.pop("mode_st")
+        panel["mode"] = panel[self.api_mode]
+        panel.pop(self.api_mode)
+
+        if self.model == 2:
+            panel["mode"] = CONST.XT2_MODES_TO_TEXT[panel["mode"]]
         panel["device_id"] = CONST.ALARM_DEVICE_ID
         panel["type"] = CONST.ALARM_TYPE
         panel["name"] = CONST.ALARM_NAME
 
         history = self.get_history()
 
-        for histrow in history:
-            if histrow not in self._history_cache:
-                if CONST.MODE_ALARM_TRIGGERED in histrow[CONST.HISTORY_ALARM_COLUMN]:
-                    panel["mode"] = CONST.STATE_ALARM_TRIGGERED
-                self._history_cache.append(histrow)
-                pickle.dump(
-                    self._history_cache,
-                    open(home + "/" + CONST.HISTORY_CACHE_NAME, "wb"),
-                )
-
+        if self.model == 1:
+            for histrow in history:
+                if histrow not in self._history_cache:
+                    if (
+                        CONST.MODE_ALARM_TRIGGERED
+                        in histrow[CONST.HISTORY_ALARM_COLUMN]
+                    ):
+                        panel["mode"] = CONST.STATE_ALARM_TRIGGERED
+                    self._history_cache.append(histrow)
+                    pickle.dump(
+                        self._history_cache,
+                        open(home + "/" + CONST.HISTORY_CACHE_NAME, "wb"),
+                    )
+        elif self.model == 2:
+            _LOGGER.debug("Alarm on XT2 not implemented")
         return panel
 
     def get_history(self):
@@ -172,7 +211,7 @@ class Lupusec:
                 if device:
                     device.update(deviceJson)
                 else:
-                    device = newDevice(deviceJson, self)
+                    device = self.newDevice(deviceJson, self)
 
                     if not device:
                         _LOGGER.info("Device is unknown")
@@ -195,22 +234,26 @@ class Lupusec:
                 self._devices["0"] = alarmDevice
 
             # Now we will handle the power switches
-            switches = self.get_power_switches()
-            _LOGGER.debug("Get active the power switches in get_devices: %s", switches)
+            if self.model == 1:
+                switches = self.get_power_switches()
+                _LOGGER.debug("Get active the power switches in get_devices: %s", switches)
 
-            for deviceJson in switches:
-                # Attempt to reuse an existing device
-                device = self._devices.get(deviceJson["name"])
+                for deviceJson in switches:
+                    # Attempt to reuse an existing device
+                    device = self._devices.get(deviceJson["name"])
 
-                # No existing device, create a new one
-                if device:
-                    device.update(deviceJson)
-                else:
-                    device = newDevice(deviceJson, self)
-                    if not device:
-                        _LOGGER.info("Device is unknown")
-                        continue
-                    self._devices[device.device_id] = device
+                    # No existing device, create a new one
+                    if device:
+                        device.update(deviceJson)
+                    else:
+                        device = self.newDevice(deviceJson, self)
+                        if not device:
+                            _LOGGER.info("Device is unknown")
+                            continue
+                        self._devices[device.device_id] = device
+
+            elif self.model == 2:
+                _LOGGER.debug("Power switches for XT2 not implemented")
 
         if generic_type:
             devices = []
@@ -243,12 +286,13 @@ class Lupusec:
         return self.get_device(CONST.ALARM_DEVICE_ID, refresh)
 
     def set_mode(self, mode):
-        r = self._request_post(
-            "panelCondPost",
-            {
+        if self.model == 1:
+            params = {
                 "mode": mode,
-            },
-        )
+            }
+        elif self.model == 2:
+            params = {"mode": mode, "area": 1}
+        r = self._request_post("panelCondPost", params)
         responseJson = self.clean_json(r.text)
         return responseJson
 
