@@ -14,5 +14,9 @@ class LupusecBinarySensor(LupusecDevice):
 
         Assume offline or open (worst case).
         """
-        return self.status not in (CONST.STATUS_OFF, CONST.STATUS_OFFLINE,
-                                   CONST.STATUS_CLOSED, CONST.STATUS_OPEN)
+        return self.status not in (
+            CONST.STATUS_OFF,
+            CONST.STATUS_OFFLINE,
+            CONST.STATUS_CLOSED,
+            CONST.STATUS_OPEN,
+        )
